@@ -16,10 +16,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 #include "config.h"
@@ -387,19 +387,19 @@ TypeId Object::AddType(string TypeName, Object*(*Create)(), TypeId id)
 		NextType = TypeId ((unsigned) NextType + 1);
 	} else
 		typedesc.Id = id;
-	if (TypeNames.capacity() <= typedesc.Id) {
+	if (TypeNames.size() <= typedesc.Id) {
 		size_t max = (((size_t) typedesc.Id / 10) + 1) * 10;
-		TypeNames.reserve (max);
-		while (max > TypeNames.size())
-			TypeNames.push_back ("");
+		TypeNames.resize (max);
 	}
 #if HAS_VECTOR_AT
-	TypeNames.at (id) = TypeName;
+	TypeNames.at (typedesc.Id) = TypeName;
 #else
 	vector<string>::iterator it;
 	it = TypeNames.begin ();
 	it += typedesc.Id;
-	TypeNames.insert (it, TypeName);
+	it = TypeNames.insert (it, TypeName);
+	it++;
+	TypeNames.erase (it);
 #endif
 	return typedesc.Id;
 }
